#!/bin/bash

# Path to MariaDB binaries
BASEDIR="$1"
if [ "$BASEDIR" = "" ]
then
   echo "You need to assign a basedir == path to MariaDB binaries like '/work_m/bb-10.2-marko/bld_asan'"
   echo "Example:         ./NewInnoDB.sh /work_m/bb-10.2-marko/bld_asan"
   exit
fi
if [ ! -d "$BASEDIR" ]
then
   echo "BASEDIR '$BASEDIR' does not exist."
   exit
fi


PROT="MDEV-17376.prt"

# My standard work directory. Results of runs are in sub directories.
BATCH_WORKDIR="storage"
mkdir $BATCH_WORKDIR

# My standard var directory on tmpfs. Ongoing RQG runs are in sub directories.
BATCH_VARDIR="/dev/shm/vardir"
mkdir $BATCH_VARDIR


# Go with heavy load
PARALLEL=`nproc`

TRIALS=$(($PARALLEL * 10))

# IMHO: A better limit than $TRIALS when running 'production'
# Please be aware that the runtime of util/issue_grep.sh is not included.
# RQG batch run elapsed runtime =
#    assigned max_runtime 
# +  time for stopping the active RQG Worker (less than 3 seconds)
# +  util/issue_grep.sh elapsed time =
#       no of logs in last_batch_workdir * (1 till 3 seconds depending on log size)
MAX_RUNTIME=3600


# Various settings for the server+InnoDB etc.
# including settings for avoiding open bugs.
CONFIG=MDEV-17376.cc


if [ ! -e "$CONFIG" ]
then
   echo "The config file '$CONFIG' does not exist."
   echo "Please adjust the setting in $0"
   exit
fi


# One 'God' only
# --------------
# in order to avoid "ill" runs where
# - current rqg_batch run ---- other ongoing rqg_batch run
# - current rqg_batch run ---- ongoing MTR run
# clash on the same resources (vardir, ports -> MTR_BUILD_THREAD) or
# suffer from tmpfs full etc.
killall -9 perl ; killall -9 mysqld
rm -rf $BATCH_VARDIR/* rm -rf /dev/shm/var_*


# 1. There should be usually sufficient space for the core files.
#    They will get immediate archived and the original gets deleted.
#    This happens around end of any single RQG run.
#    In addition rqg_batch.pl most probably also tries to deleted the vardir
#    of some RQG worker.
# 2. If its not an ASAN build than its harmless.
export ASAN_OPTIONS=abort_on_error=1,disable_coredump=0
echo "Have set"`env | grep ASAN`

GRAMMAR=MDEV-17376.yy
vi $GRAMMAR
rm -f $PROT

set -o pipefail
# Remove the logs of RQG runs achieving STATUS_OK/verdict 'ignore'.
# Their stuff grammar/datadir was not archived and is already thrown away.
# So basically:
# Remove the --discard_logs incase you want to see logs of RQG runs which pass.
# --discard_logs Remove the logs of RQG runs achieving STATUS_OK/verdict 'ignore'
#
# Do not abort if hitting Perl errors or STATUS_ENVIRONMENT_FAILURE. Questionable
# --force
#
# Old stuff. In history required.
# --no-mask  Unclear if ./rqg_batch.pl and rqg.pl will mask at all.
#
# The RQG Worker prints how he would start the RQG runner (rqg.pl)
# but will not do the RQG run at all.
# --dryrun                                                        \
#
# rqg_batch stops immediate if hitting a 'replay'
# --stop_on_replay                                                \
nohup nice -19 perl ./rqg_batch.pl                              \
--workdir=$BATCH_WORKDIR                                        \
--vardir=$BATCH_VARDIR                                          \
--parallel=$PARALLEL                                            \
--basedir1=$BASEDIR                                             \
--config=$CONFIG                                                \
--grammar=$GRAMMAR                                              \
--trials=$TRIALS                                                \
--max_runtime=$MAX_RUNTIME                                      \
--stop_on_replay                                                \
--no-mask                                                       \
--discard_logs                                                  \
--force                                                         \
2>&1 > $PROT &
tail -f $PROT

